@@ -25,6 +25,7 @@ module Gem2Deb
       bin/console
       bin/setup
       debian/*
+      examples/*
       features/*
       gemfiles/*
       spec/*
@@ -81,6 +82,8 @@ module Gem2Deb
           ['console', 'setup'].include?(prog)
         end
 
+        gemspec_data.extra_rdoc_files = []
+
         # write modified gemspec at temporary directory
         gemspec = File.join(tmpdir, 'gemspec')
         File.open(gemspec, 'w') do |f|
@@ -154,7 +157,7 @@ module Gem2Deb
         end
 
         # remove tmpdir
-        FileUtils.rm_f(tmpdir)
+        FileUtils.rm_rf(tmpdir)
 
         done = true
       end
